@@ -1,14 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "sumibi" "4.1.0"
+(define-package "sumibi" "4.2.0"
   "Japanese input method powered by ChatGPT API."
   '((emacs          "29.0")
     (popup          "0.5.9")
     (unicode-escape "1.1")
-    (deferred       "0.5.1")
-    (mozc           "0"))
+    (deferred       "0.5.1"))
   :url "https://github.com/kiyoka/Sumibi"
-  :commit "b360b7ad9b6cc9b935cdc5a73ddb40e5b3aae7dc"
-  :revdesc "4.1.0-0-gb360b7ad9b6c"
+  :commit "47ecde2e815e4540bbb110bee1c0d5c50569f6f8"
+  :revdesc "4.2.0-0-g47ecde2e815e"
   :keywords '("lisp" "ime" "japanese")
   :authors '(("Kiyoka Nishiyama" . "kiyoka@sumibi.org"))
   :maintainers '(("Kiyoka Nishiyama" . "kiyoka@sumibi.org")))
